@@ -3,7 +3,7 @@ from typing import Optional, Union
 
 from brain_brew.configuration.representation_base import RepresentationBase
 from brain_brew.interfaces.yamale_verifyable import YamlRepr
-from brain_brew.representation.yaml.notes import Notes, Note
+from brain_brew.representation.yaml.notes import Note
 
 
 @dataclass
@@ -26,9 +26,11 @@ class NotesOverride(YamlRepr):
     def from_repr(cls, data: Union[Representation, dict]):
         rep: cls.Representation = data if isinstance(data, cls.Representation) else cls.Representation.from_dict(data)
         return cls(
+            rep=rep,
             note_model=rep.note_model
         )
 
+    rep: Representation
     note_model: Optional[str]
 
     def override(self, note: Note):
